@@ -88,12 +88,16 @@ public class ConfigCto {
     @JsonInclude(JsonInclude.Include.NON_EMPTY)
     List<CapabilityCto> capabilities;
 
+    @JsonInclude(JsonInclude.Include.NON_DEFAULT)
+    boolean multipleAccountsEnabled;
+
     public ConfigCto(Config config) {
         purgeOnDeletion = config.isPurgeOnDeletion();
         maxSize = config.getMaxSize();
         maxAttachmentSize = config.getMaxAttachmentSize();
         deleteDraftOnTransport = config.isDeleteDraftOnTransport();
         capabilities = ListUtil.map(config.getCapabilities(), capabilitiesMapFunction);
+        multipleAccountsEnabled = config.isMultipleAccountsEnabled();
     }
 
 }
